from setuptools import setup, find_packages
import codecs
import os



VERSION = '0.1'
DESCRIPTION = 'This package allow you to import 255+ color to change the color of output in terminal'

# Setting up
setup(
    name="illusioncolor",
    version=VERSION,
    author="KDO (Team Illusion)",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Android",
    ]

)